@@ -142,6 +142,8 @@ mod tests {
     use std::panic;
     use crate::parser::model::JsonPath::{Chain, Current, Field, Descent, Wildcard};
     use serde_json::{json};
+    use crate::parser::model::FilterSign::Equal;
+    use crate::parser::model::Operand::{Dynamic, Static};
 
     fn test_failed(input: &str) {
         match parse_json_path(input) {
@@ -244,6 +246,18 @@ mod tests {
         test_failed("[\"abc\",\"bcd\"]");
     }
 
+    #[test]
+    fn array_start_test() {
+        test("$.[?(@.verb== 'TEST')]", vec![
+            JsonPath::Root,
+            JsonPath::Index(
+                JsonPathIndex::Filter(
+                    Dynamic(Box::new(Chain(vec![Current(Box::new(Chain(vec![Field("verb".to_string())])))]))),
+                    Equal,
+                    Static(Value::from("TEST"))
+                ))]);
+    }
+
     #[test]
     fn index_filter_test() {
         test("[?('abc' == 'abc')]", vec![JsonPath::Index(JsonPathIndex::Filter(
